---
orphan: true
---



# Installation

You can install ZeusDB Vector Database with 'uv' or alternatively using 'pip'.


Recommended (with uv):
```python
uv pip install zeusdb
```

Alternatively (just with pip):
```{code-block} python
pip install zeusdb
```

<br />

## Python version support
Officially Python 3.10, 3.11, 3.12 and 3.13.

<br />

## Dependencies

| Package | Minimum required version |
|---------|---------------------------|
| [NumPy](https://numpy.org/) | 2.2.6 |
| [zeusdb-vector-database](https://github.com/ZeusDB/zeusdb-vector-database) | 0.3.0 |
